%% demo_scriptScale.m
% 
% demo file for the joint Bayesian estimation of the multifractality parameter c2
% and the integral scale J of (AD) time series
%
% Please refer to the help of the functions c2BayesSeriesScale.m for details on usage and output.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%--- Sebastien Combrexelle, Toulouse, 2014-2015
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% If you use this code, please quote:
%
% @INPROCEEDINGS{CombrexelleICASSP15,
%   author = {Sebastien Combrexelle and Herwig Wendt and Patrice Abry and Nicolas Dobigeon and Stephen McLaughlin and Jean-Yves Tourneret},
%   title = {A Bayesian approach for the joint estimation of the multifractality parameter and integral scale based on the Whittle approximation},
%   booktitle = {IEEE Int. Conf. Acoust., Speech, and Signal Proc. (ICASSP)},
%   address = {Brisbane, Australia},
%   month = {April},
%   year = {2015}
% }
%
% and
%
% @INPROCEEDINGS{WendtICASSP2013,
%   author = {Herwig Wendt and Nicolas Dobigeon and Jean-Yves Tourneret and Patrice Abry},
%   title = {Bayesian estimation for the multifractality parameter},
%   booktitle = {IEEE Int. Conf. Acoust., Speech, and Signal Proc. (ICASSP)},
%   address = {Vancouver, Canada},
%   month = {September},
%   year = {2013}
% }
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


clear all;
clc
pp=which('demo_scriptScale');if ispc;id=strfind(pp,'\');else;id=strfind(pp,'/');end;addpath(genpath(pp(1:id(end))));


% generate synthetic time series
N = 2^16; c2 = -0.03;H=0.72 ; J = 8; % ICASSP
[data0] = mrw(H,sqrt(abs(c2)),N/(2^(log2(N)-J))+1,N+1,2) ;  X = cumsum(data0(2:end));
disp(['estimation for time series (N=',num2str(N),', c2=',num2str(c2),', J=',num2str(J),'):']);

% estimation
Nwt = 2;    % number of vanishing moments (wavelet)
j1=3; j2=6; % range of scales for estimation
tic; [EST,TAB] = c2BayesSeriesScale(X,j1,j2,Nwt,1); toc;

% display
disp('estimates of c2:')
Est_c2 = EST.c2
disp('estimates of integral scale:')
Est_J = EST.J
figure(1);clf;hold on;grid on;plot(X);axis tight;title(['1D MRW c_2=',num2str(c2),'J=',num2str(J)]);disp(' ');

